//  const node = ogma.addNode({id: 0});
//
//  ogma.styles.setSelectedNodeAttributes({outerStroke: {color: 'green'}});
//  node.setSelected(true);
//  node.locate();
//
//  console.log(node.getAttribute('outerStroke.color')); // "green"

//  const node = ogma.addNode({id: 0, data: {name: 'John'}});
//
//  ogma.styles.setSelectedNodeAttributes({
//    outerStroke: {
//      color: 'green'
//    },
//    text: function (node) {
//      return node.getData('name');
//    }
//  });
//
//  node.locate();
//
//  console.log(node.getAttribute('text')); // null
//  node.setSelected(true);
//  console.log(node.getAttribute('text')); // "John"

export function demoClasses(ogma) {
  // Generate a grid
  ogma.generate
    .grid({ rows: 5, columns: 5 })
    .then(graph => {
      return ogma.setGraph(graph);
    })
    // Remove a few edges to make things more interesting
    .then(() => ogma.removeEdges([0, 2, 3, 5, 7, 10, 13, 14, 18, 19, 22]))
    .then(() => ogma.view.locateGraph());

  // Define the class, and the attributes associated to it
  let myClass = ogma.styles.createClass({
    name: 'shortestPathHighlight',
    nodeAttributes: { outerStroke: { color: 'black', width: 10 } },
    edgeAttributes: { strokeWidth: 5, color: 'black' }
  });

  ogma.events.on('click', evt => {
    if (evt.button !== 'right') return;

    // This is the node that will be used to compute the shortest path
    let sourceNode = ogma.getNode(0);

    // When the user right clicks, first clear the current highlighted shortest path, if any
    myClass.clearNodes();
    myClass.clearEdges();

    // If a node was right clicked, highlight the shortest path
    if (evt.target && evt.target.isNode) {
      let shortestPath = ogma.pathfinding.dijkstra(sourceNode, evt.target);

      // `shortestPath` is null if no path exists
      if (shortestPath) {
        // Highlight all the nodes in the shortest path
        shortestPath.addClass('shortestPathHighlight');

        // Get all the edges that connect the nodes of the shortest path together, and highlight them
        shortestPath
          .getAdjacentEdges()
          .filter(edge => {
            return (
              shortestPath.includes(edge.getSource()) &&
              shortestPath.includes(edge.getTarget())
            );
          })
          .addClass('shortestPathHighlight');
      }
    }
  });
}
